@@ -1,6 +1,7 @@
 from django import template
 from django.conf import settings
 from django.utils.translation import ugettext as _
+from django.utils.formats import number_format
 
 register = template.Library()
 
@@ -8,7 +9,7 @@ register = template.Library()
 @register.simple_tag(takes_context=True)
 def querystring(context, **kwargs):
     args = context['request'].GET.copy()
-    for k, v in kwargs.iteritems():
+    for k, v in kwargs.items():
         args[k] = v
     return args.urlencode()
 
@@ -35,19 +36,8 @@ def sortanchor(parser, token):
         raise template.TemplateSyntaxError(
                         "anchor tag takes at least 1 argument.")
 
-    title_is_var = False
     try:
         title = bits[2]
-        if title[0] in ('"', "'"):
-            if title[0] == title[-1]:
-                title = title[1:-1]
-            else:
-                raise template.TemplateSyntaxError('sortanchor tag title '
-                        'must be a "string", _("trans string"), or variable')
-        elif title.startswith('_("') or title.startswith("_('"):
-            title = _(title[3:-2])
-        else:
-            title_is_var = True
     except IndexError:
         title = bits[1].capitalize()
 
@@ -56,8 +46,7 @@ def sortanchor(parser, token):
     else:
         default = False
 
-    return SortAnchorNode(bits[1].strip(), title.strip(), title_is_var,
-                                        default)
+    return SortAnchorNode(bits[1].strip(), title, default)
 
 
 class SortAnchorNode(template.Node):
@@ -72,15 +61,29 @@ class SortAnchorNode(template.Node):
         <a href="/the/current/path/?sort=name" title="Name">Name</a>
 
     """
-    def __init__(self, field, title, title_is_var, is_default):
+    def __init__(self, field, title, is_default):
         self.field = field
         self.title = title
-        self.title_is_var = title_is_var
         self.is_default = is_default
 
     def render(self, context):
-        if self.title_is_var:
-            self.title = context[self.title]
+
+        title = self.title
+
+        if title[0] in ('"', "'"):
+            if title[0] == title[-1]:
+                title = title[1:-1]
+            else:
+                raise template.TemplateSyntaxError(
+                        'sortanchor tag title '
+                        'must be a "string", _("trans string"), or variable'
+                        )
+        elif title.startswith('_("') or title.startswith("_('"):
+            title = _(title[3:-2])
+        else:
+            #  Title is var
+            title = context[title]
+
         request = context['request']
         getvars = request.GET.copy()
 
@@ -88,31 +91,49 @@ class SortAnchorNode(template.Node):
         sortby = self.field
         icon = False
 
+        def invert_order(fields):
+            res = []
+            for field in fields.split(","):
+                if field.startswith("-"):
+                    res.append(field[1:])
+                else:
+                    res.append("-" + field)
+            return ",".join(res)
+
         if SORT_FIELD in getvars:
             currentsort = getvars[SORT_FIELD]
         else:
             if self.is_default:
                 if self.is_default == '-':
-                    currentsort = '-' + self.field
+                    currentsort = invert_order(self.field)
                 else:
                     currentsort = self.field
 
         if currentsort == self.field:
-            sortby = "-" + self.field
+            sortby = invert_order(self.field)
             icon = SORT_DOWN_ICON
 
-        if currentsort.startswith('-') and currentsort[1:] == self.field:
+        if invert_order(currentsort) == self.field:
             icon = SORT_UP_ICON
 
         if icon:
-            title = "%s %s" % (self.title, icon)
+            title = "%s %s" % (title, icon)
         else:
-            title = self.title
+            title = title
 
         getvars[SORT_FIELD] = sortby
 
         url = '%s?%s' % (request.path, getvars.urlencode())
-        return '<a href="%s" title="%s">%s</a>' % (url, self.title, title)
+        return '<a href="%s" title="%s">%s</a>' % (url, title, title)
 
 
 sortanchor = register.tag(sortanchor)
+
+
+@register.filter
+def money_format(num):
+    if num is None:
+        return ""
+    if isinstance(num, str):
+        return num
+    return number_format(num, decimal_pos=2, force_grouping=True)
